;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "god-mode" "20250820.259"
  "Minor mode for God-like command entering."
  '((emacs "26.3"))
  :url "https://github.com/emacsorphanage/god-mode"
  :commit "e6eef24dbf739d819a6651e854ec732ac3f386e6"
  :revdesc "e6eef24dbf73"
  :authors '(("Chris Done" . "chrisdone@gmail.com"))
  :maintainers '(("Chris Done" . "chrisdone@gmail.com")))
